/* $Id: version.h.in,v 1.1 2005/04/08 01:49:35 rockyb Exp $ */
/** \file version.h 
 *
 *  \brief A file containing the libcdio package version
 *  number (131) and OS build name. 
 */

/*! CDDB_VERSION can as a string in programs to show what version is used. */
#define CDDB_VERSION "1.3.2 aarch64-unknown-openbsd7.4"

/*! LIBCDDB_VERSION_NUM  can be used for testing in the C preprocessor */
#define LIBCDDB_VERSION_NUM 131
