/*
    $Id: cddb_config.h.in,v 1.3 2005/03/11 21:29:29 airborne Exp $

    Copyright (C) 2004, 2005 Kris Verbeeck <airborne@advalvas.be>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public
    License along with this library; if not, write to the
    Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA  02111-1307, USA.
*/

#ifndef CDDB_CONFIG_H
#define CDDB_CONFIG_H 1

/* Define if you have <unistd.h> and need it included. 
   On MacOS, <regex.h> needs this but that header doesn't
   include it.
*/
#undef CDDB_NEED_UNISTD_H

/* Define if you have <sys/socket.h> and need it included. 
   On MacOS, <cddb_net.h> needs this but that header doesn't
   include it.
*/
#undef CDDB_NEED_SYS_SOCKET_H

#endif /* CDDB_CONFIG_H */
